<?xml version="1.0" encoding="windows-1250"?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:import href="file:///e:/src/db2latex/docbook/latex/docbook.xsl"/>

<xsl:output method="text" encoding="windows-1250"/>

<xsl:variable name="latex.mapping.xml" select="document('latex.mapping.xml')"/>

<xsl:variable name="latex.use.babel">0</xsl:variable>
<xsl:variable name="latex.use.isolatin1">0</xsl:variable>
<xsl:variable name="latex.use.subfigure">0</xsl:variable>
<xsl:variable name="latex.math.support">0</xsl:variable>
<xsl:variable name="latex.toc" select="'1'"/>
<xsl:variable name="latex.titlepage.file">coverpage.tex</xsl:variable>

<xsl:param name="latex.biblio.output"/>
<xsl:param name="latex.bibwidelabel">99</xsl:param>

<xsl:param name="section.depth" select="3"/>
<xsl:param name="toc.section.depth" select="2"/>

<xsl:template match="book">
<xsl:call-template name="generate.latex.book.preamble"/>
<!-- Output title information -->
<xsl:text>\title{</xsl:text>
	<xsl:choose>
            <xsl:when test="./title">
			<xsl:value-of select="normalize-space(./title)"/>
            </xsl:when>
            <xsl:otherwise>
			<xsl:value-of select="normalize-space(./bookinfo/title)"/>
            </xsl:otherwise>
	</xsl:choose>
<xsl:text>}&#10;</xsl:text>
<!-- Output author information -->
<xsl:text>\author{</xsl:text>
	<xsl:choose>
            <xsl:when test="bookinfo/authorgroup">
      		<xsl:apply-templates select="bookinfo/authorgroup"/>
            </xsl:when>
            <xsl:otherwise>
      		<xsl:apply-templates select="bookinfo/author"/>
            </xsl:otherwise>
	</xsl:choose>
<xsl:text>}&#10;</xsl:text>

<xsl:value-of select="$latex.book.afterauthor"/>
<xsl:text>&#10;\setcounter{tocdepth}{</xsl:text><xsl:value-of select="$toc.section.depth"/><xsl:text>}&#10;</xsl:text>
<xsl:text>&#10;\setcounter{secnumdepth}{</xsl:text><xsl:value-of select="$section.depth"/><xsl:text>}&#10;</xsl:text>
<xsl:value-of select="$latex.book.begindocument"/>
<!-- Include external Cover page if specified -->
<xsl:text>&#10;\InputIfFileExists{</xsl:text><xsl:value-of select="$latex.titlepage.file"/>
<xsl:text>}{\typeout{WARNING: Using cover page</xsl:text>
<xsl:value-of select="$latex.titlepage.file"/>
<xsl:text>}}</xsl:text>
<xsl:text>{\maketitle}&#10;</xsl:text>
<xsl:if test="$latex.toc='1'"> 
  <xsl:text>\tableofcontents&#10;</xsl:text>
</xsl:if>
<!-- APPLY TEMPLATES -->
<xsl:apply-templates/>
<xsl:call-template name="map.end"/>
</xsl:template>

<xsl:variable name="latex.book.preamblestart">
<xsl:text>% --------------------------------------------	&#10;</xsl:text>
<xsl:text>% This is an example 					&#10;</xsl:text>
<xsl:text>% Adding a customization Layer			&#10;</xsl:text>
<xsl:text>% Autogenerated LaTeX file for books 			&#10;</xsl:text>
<xsl:text>% --------------------------------------------	&#10;</xsl:text>
<!-- <xsl:text>\documentclass[spanish,french,english,a4paper,12pt,final]{report}&#10;</xsl:text> -->
<xsl:text>\documentclass[a4paper,12pt,final]{report}&#10;</xsl:text>
<xsl:text>\usepackage{czech}&#10;</xsl:text>
<xsl:text>\def\footeat#1{}&#10;</xsl:text>
<xsl:text>\clubpenalty=10000&#10;</xsl:text>
<xsl:text>\widowpenalty=10000&#10;</xsl:text>
<xsl:text>\emergencystretch=1em&#10;</xsl:text>
</xsl:variable>

<xsl:variable name="latex.book.varsets">
<xsl:text>\setlength{\textwidth}{17cm}&#10;</xsl:text>
<xsl:text>\setlength{\textheight}{24.5cm}&#10;</xsl:text>
<xsl:text>\setlength{\hoffset}{-1.5cm}&#10;</xsl:text>
<xsl:text>\setlength{\voffset}{-1.5cm}&#10;</xsl:text>
</xsl:variable>

<xsl:variable name="latex.book.afterauthor">
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<!--
<xsl:text>\makeindex&#10;</xsl:text>
<xsl:text>\makeglossary&#10;</xsl:text>
-->
<xsl:text>% --------------------------------------------&#10;</xsl:text>
</xsl:variable>

<xsl:template name="latex.hyperref.preamble">
<xsl:if test="$latex.pdf.support=1">
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>% Load hyperref package with pdf if needed &#10;</xsl:text>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>\ifpdf&#10;</xsl:text>
<xsl:text>\usepackage[pdftex,bookmarksnumbered, bookmarks, breaklinks, linktocpage]{hyperref}&#10;</xsl:text>
<xsl:text>\else&#10;</xsl:text>
<xsl:text>\usepackage[dvips,bookmarksnumbered,colorlinks,backref, bookmarks, breaklinks, linktocpage]{hyperref}&#10;</xsl:text>
<xsl:text>\fi&#10;</xsl:text>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
</xsl:if>
<xsl:if test="$latex.pdf.support=0">
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>% Load hyperref package &#10;</xsl:text>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>\usepackage[dvips,bookmarksnumbered,colorlinks,backref, bookmarks, breaklinks, linktocpage]{hyperref}&#10;</xsl:text>
</xsl:if>
</xsl:template>

<xsl:template name="generate.latex.common.preamble">
<xsl:if test="$latex.pdf.support=1"><xsl:value-of select="$latex.pdf.preamble"/></xsl:if>
<xsl:if test="$latex.pdf.support=0"><xsl:text>\usepackage{graphicx}&#10;</xsl:text> </xsl:if>
<xsl:if test="local-name(.)='article'">
	<xsl:value-of select="$latex.article.varsets"/>
</xsl:if>
<xsl:if test="local-name(.)='book'">
	<xsl:value-of select="$latex.book.varsets"/>
</xsl:if>
<xsl:if test="$latex.use.fancyhdr=1">
<xsl:text>\usepackage{fancyhdr}&#10;</xsl:text>
<xsl:text>\pagestyle{fancy}&#10;</xsl:text>
<xsl:text>\lhead{}&#10;</xsl:text>
<xsl:text>\chead{}&#10;</xsl:text>
<xsl:text>\renewcommand{\chaptermark}[1]{\markright{#1}}&#10;</xsl:text>
<xsl:text>\rhead{\slshape \rightmark}&#10;</xsl:text>
<xsl:text>\lfoot{}&#10;</xsl:text>
<xsl:text>\cfoot{\thepage}&#10;</xsl:text>
<xsl:text>\rfoot{}&#10;</xsl:text>
<xsl:text>\renewcommand{\headrulewidth}{0.4pt}&#10;</xsl:text>
<xsl:text>\renewcommand{\footrulewidth}{0pt}&#10;</xsl:text>
<!-- Add dollar...
<xsl:if test="latex.fancyhdr.lh !=''"><xsl:text>\lhead{</xsl:text><xsl:value-of select="$latex.fancyhdr.lh"/><xsl:text>}&#10;</xsl:text></xsl:if>
<xsl:if test="latex.fancyhdr.ch !=''"><xsl:text>\chead{</xsl:text><xsl:value-of select="$latex.fancyhdr.ch"/><xsl:text>}&#10;</xsl:text></xsl:if>
<xsl:if test="latex.fancyhdr.rh !=''"><xsl:text>\rhead{</xsl:text><xsl:value-of select="$latex.fancyhdr.rh"/><xsl:text>}&#10;</xsl:text></xsl:if>
<xsl:if test="latex.fancyhdr.lf !=''"><xsl:text>\lfoot{</xsl:text><xsl:value-of select="$latex.fancyhdr.lf"/><xsl:text>}&#10;</xsl:text></xsl:if>
<xsl:if test="latex.fancyhdr.cf !=''"><xsl:text>\cfoot{</xsl:text><xsl:value-of select="$latex.fancyhdr.cf"/><xsl:text>}&#10;</xsl:text></xsl:if>
<xsl:if test="latex.fancyhdr.rf !=''"><xsl:text>\rfoot{</xsl:text><xsl:value-of select="$latex.fancyhdr.rf"/><xsl:text>}&#10;</xsl:text></xsl:if> 
-->
</xsl:if>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>% Most Common Packages (? need guru hint)  &#10;</xsl:text>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:if test="$latex.use.makeidx=1"><xsl:text>\usepackage{makeidx}         &#10;</xsl:text></xsl:if>
<xsl:text>\usepackage{varioref}         &#10;</xsl:text>
<xsl:text>\usepackage{fancybox}         &#10;</xsl:text>
<xsl:text>\usepackage{latexsym}         &#10;</xsl:text>
<xsl:text>\usepackage{enumerate}         &#10;</xsl:text>
<xsl:text>\usepackage{rotating}       &#10;</xsl:text>
<xsl:text>\usepackage{float}       &#10;</xsl:text>
<xsl:text>\usepackage{listing}&#10;</xsl:text>
<xsl:text>\renewcommand{\listingname}{Pklad}
\renewcommand{\listlistingname}{Seznam pklad}&#10;</xsl:text>

<xsl:if test="$latex.use.babel=1"><xsl:text>\usepackage{babel} &#10;</xsl:text></xsl:if>
<xsl:if test="$latex.use.isolatin1=1"><xsl:text>\usepackage{isolatin1}         &#10;</xsl:text></xsl:if>
<xsl:if test="$latex.use.fancyvrb=1"><xsl:text>\usepackage{fancyvrb}         &#10;</xsl:text></xsl:if>
<xsl:if test="$latex.use.subfigure=1"><xsl:text>\usepackage{subfigure}         &#10;</xsl:text></xsl:if>
<xsl:if test="$latex.document.font != 'default'">
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>% Document Font  &#10;</xsl:text>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>\usepackage{</xsl:text><xsl:value-of select="$latex.document.font"/>	<xsl:text>}&#10;</xsl:text>
</xsl:if>
<xsl:if test="$latex.math.support=1"><xsl:value-of select="$latex.math.preamble"/></xsl:if>
<xsl:if test="$latex.use.hyperref=1"><xsl:call-template name="latex.hyperref.preamble"/></xsl:if>
<xsl:if test="$latex.use.hyperref=0">
	<xsl:text>\newcommand{\href}[1]{{}}&#10;</xsl:text>
	<xsl:text>\newcommand{\hyperlink}[1]{{}}&#10;</xsl:text>
	<xsl:text>\newcommand{\hypertarget}[2]{#2}&#10;</xsl:text>
</xsl:if>
<xsl:value-of select="$latex.admonition.environment"/>
<xsl:call-template name="latex.float.preamble"/>
<xsl:call-template name="latex.graphicext"/>
</xsl:template>

<xsl:template name="latex.float.preamble">
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<xsl:text>% Commands to manage/style/create floats      &#10;</xsl:text>
<xsl:text>% figures, tables, algorithms, examples, eqn  &#10;</xsl:text>
<xsl:text>% --------------------------------------------&#10;</xsl:text>
<!--<xsl:text> \floatstyle{ruled}&#10;</xsl:text>
<xsl:text> \restylefloat{figure}&#10;</xsl:text>
<xsl:text> \floatstyle{ruled}&#10;</xsl:text>
<xsl:text> \restylefloat{table}&#10;</xsl:text>
<xsl:text> \floatstyle{ruled}&#10;</xsl:text>
<xsl:text> \newfloat{program}{ht}{lop}[section]&#10;</xsl:text>
<xsl:text> \floatstyle{ruled}&#10;</xsl:text>
<xsl:text> \newfloat{example}{ht}{loe}[section]&#10;</xsl:text>
<xsl:text> \floatname{example}{</xsl:text>
	<xsl:call-template name="gentext.element.name">
	<xsl:with-param name="element.name">example</xsl:with-param>
	</xsl:call-template>
	<xsl:text>}&#10;</xsl:text>
<xsl:text> \floatstyle{ruled}&#10;</xsl:text>
<xsl:text> \newfloat{dbequation}{ht}{loe}[section]&#10;</xsl:text>
<xsl:text> \floatname{dbequation}{</xsl:text>
	<xsl:call-template name="gentext.element.name">
	<xsl:with-param name="element.name">equation</xsl:with-param>
	</xsl:call-template>
	<xsl:text>}&#10;</xsl:text>
<xsl:text> \floatstyle{boxed}&#10;</xsl:text>
<xsl:text> \newfloat{algorithm}{ht}{loa}[section]&#10;</xsl:text>
<xsl:text> \floatname{algorithm}{Algorithm}&#10;</xsl:text> -->
</xsl:template>

<xsl:template match="section">
<xsl:text>&#10;</xsl:text>
<xsl:variable name="level" select="count(ancestor::section)+1"/>
<xsl:choose>
		<xsl:when test='$level=1'>
		<xsl:call-template name="map.begin">
			<xsl:with-param name="keyword" select="'sect1'"/>
		</xsl:call-template>
		</xsl:when>
		<xsl:when test='$level=2'>
		<xsl:call-template name="map.begin">
			<xsl:with-param name="keyword" select="'sect2'"/>
		</xsl:call-template>
		</xsl:when>
		<xsl:when test='$level=3'>
		<xsl:call-template name="map.begin">
			<xsl:with-param name="keyword" select="'sect3'"/>
		</xsl:call-template>
		</xsl:when>
		<xsl:when test='$level=4'>
		<xsl:call-template name="map.begin">
			<xsl:with-param name="keyword" select="'sect4'"/>
		</xsl:call-template>
		</xsl:when>
		<xsl:when test='$level=5'>
		<xsl:call-template name="map.begin">
			<xsl:with-param name="keyword" select="'sect5'"/>
		</xsl:call-template>
		</xsl:when>
		<xsl:otherwise> 
		<xsl:message>DB2LaTeX: recursive section|simplesect &gt; 5 Not  well Supported</xsl:message> 
		<xsl:call-template name="map.begin">
			<xsl:with-param name="keyword" select="sect6"/>
		</xsl:call-template>
		</xsl:otherwise>
</xsl:choose>
<xsl:apply-templates/>
</xsl:template>

<!-- custom templates -->
<xsl:template match="ulink">
  <xsl:choose>
    <xsl:when test="@url = .">
      <xsl:text>\url{</xsl:text>
      <xsl:value-of select="."/>
      <xsl:text>}</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="."/>
      <xsl:if test="starts-with(following-sibling::text(),',')">,</xsl:if>
      <xsl:if test="starts-with(following-sibling::text(),'.')">.</xsl:if>
      <xsl:text>\footnote{\url{</xsl:text>
      <xsl:call-template name="string-replace">
        <xsl:with-param name="to">\#</xsl:with-param>
        <xsl:with-param name="from">#</xsl:with-param>
        <xsl:with-param name="string" select="@url"/>
      </xsl:call-template>
      <xsl:text>}}</xsl:text>
      <xsl:if test="starts-with(following-sibling::text(),',')">\footeat</xsl:if>
      <xsl:if test="starts-with(following-sibling::text(),'.')">\footeat</xsl:if>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="number.xref">
<xsl:text>\ref{</xsl:text><xsl:value-of select="@id"/><xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="imagedata">
<xsl:variable name="filename" select="@fileref"> </xsl:variable>
<xsl:variable name="ext">
	<xsl:call-template name="filename-extension">
	<xsl:with-param name="filename" select="$filename"/>
	</xsl:call-template>
</xsl:variable>
<xsl:text>{\includegraphics[width=.</xsl:text>
<xsl:choose>
	<xsl:when test="@scale"> 
		<xsl:value-of select="normalize-space(@scale)"/><xsl:text>\linewidth</xsl:text>
	</xsl:when>
	<xsl:otherwise><xsl:text>7\linewidth</xsl:text></xsl:otherwise>
</xsl:choose>
<xsl:choose>
	<xsl:when test="@format = 'PRN'"><xsl:text>, angle=270</xsl:text></xsl:when>
</xsl:choose>
<xsl:text>]{</xsl:text>
<xsl:choose><!-- package graphicx and DeclareGraphicExtensions will take care of this -->
	<xsl:when test="$ext != ''">
		<xsl:value-of select="$filename"/>
	</xsl:when>
	<xsl:otherwise> 
		<xsl:value-of select="$filename"/>
	</xsl:otherwise>
</xsl:choose>
<xsl:text>}}\quad&#10;</xsl:text>
</xsl:template>

<xsl:template match="mediaobject">
  <xsl:apply-templates select="imageobject[imagedata/@format='PNG' or imagedata/@format='PDF'][1]"/>
</xsl:template>

<xsl:template name="scape" >
<xsl:param name="string"/>
<xsl:call-template name="string-replace">
  <xsl:with-param name="to">--</xsl:with-param>
  <xsl:with-param name="from">&#x2013;</xsl:with-param>
  <xsl:with-param name="string">
  <xsl:call-template name="string-replace">
    <xsl:with-param name="to">~</xsl:with-param>
    <xsl:with-param name="from">&#160;</xsl:with-param>
    <xsl:with-param name="string">
      <xsl:call-template name="string-replace">
        <xsl:with-param name="to">$&lt;$</xsl:with-param>
        <xsl:with-param name="from">&lt;</xsl:with-param>
        <xsl:with-param name="string">
          <xsl:call-template name="string-replace">
            <xsl:with-param name="to">$&gt;$</xsl:with-param>
            <xsl:with-param name="from">&gt;</xsl:with-param>
            <xsl:with-param name="string">
              <xsl:call-template name="string-replace">
                <xsl:with-param name="to">\{</xsl:with-param>
                <xsl:with-param name="from">{</xsl:with-param>
                <xsl:with-param name="string">
                  <xsl:call-template name="string-replace">
                    <xsl:with-param name="to">\}</xsl:with-param>
                    <xsl:with-param name="from">}</xsl:with-param>
                    <xsl:with-param name="string">
                      <xsl:call-template name="string-replace">
                        <xsl:with-param name="to">\&amp;</xsl:with-param>
                        <xsl:with-param name="from">&amp;</xsl:with-param>
                        <xsl:with-param name="string">
                          <xsl:call-template name="string-replace">
                            <xsl:with-param name="to">\#</xsl:with-param>
                            <xsl:with-param name="from">#</xsl:with-param>
                            <xsl:with-param name="string">
                              <xsl:call-template name="string-replace">
                                <xsl:with-param name="to">\_</xsl:with-param>
                                <xsl:with-param name="from">_</xsl:with-param>
                                <xsl:with-param name="string">
                                  <xsl:call-template name="string-replace">
                                    <xsl:with-param name="to">\$</xsl:with-param>
                                    <xsl:with-param name="from">$</xsl:with-param>
                                    <xsl:with-param name="string">
                                      <xsl:call-template name="string-replace">
                                        <xsl:with-param name="to">\%</xsl:with-param>
                                        <xsl:with-param name="from">%</xsl:with-param>
                                        <xsl:with-param name="string">
                                          <xsl:call-template name="string-replace">
                                            <xsl:with-param name="to">$\backslash$</xsl:with-param>
                                            <xsl:with-param name="from">\</xsl:with-param>
                                            <xsl:with-param name="string" select="$string"/>
                                          </xsl:call-template>
                                        </xsl:with-param>
                                      </xsl:call-template>
                                    </xsl:with-param>
                                  </xsl:call-template>
                                </xsl:with-param>
                              </xsl:call-template>
                            </xsl:with-param>
                          </xsl:call-template>
                        </xsl:with-param>
                      </xsl:call-template>
                    </xsl:with-param>
                  </xsl:call-template>
                </xsl:with-param>
              </xsl:call-template>
            </xsl:with-param>
          </xsl:call-template>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:with-param>
  </xsl:call-template>
</xsl:with-param>
</xsl:call-template>
</xsl:template>

<xsl:template name="label.id">
<xsl:param name="object" 	select="."/>
<xsl:variable name="id">
	<xsl:choose>
	<xsl:when test="$object/@id">
		<xsl:value-of select="$object/@id"/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="generate-id($object)"/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:text>\label{</xsl:text><xsl:value-of select="normalize-space($id)"/><xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="footnote">
<xsl:call-template name="label.id"/>
<xsl:text>\footnote{</xsl:text>
<xsl:apply-templates/>
<xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="footnote/para">
<xsl:apply-templates/>
</xsl:template>

<!-- literatura -->
<xsl:key name="bib" match="//biblioentry" use="abbrev"/>

<xsl:template match="citation">
<!-- todo: biblio-citation-check -->
<xsl:text>\cite{</xsl:text>
<xsl:value-of select="count(key('bib',.)/preceding-sibling::biblioentry)+1"/>
<xsl:text>}</xsl:text>
</xsl:template>              

<xsl:template match="abbrev" mode="bibliography.mode">
<xsl:value-of select="count(../preceding-sibling::biblioentry)+1"/>
</xsl:template>

<xsl:template match="abbrev">
<xsl:value-of select="count(../preceding-sibling::biblioentry)+1"/>
</xsl:template>

<xsl:template match="bibliography">
<xsl:message>DB2LaTeX: Processing BIBLIOGRAPHY</xsl:message>
<xsl:message>DB2LaTeX: Output Mode :  <xsl:value-of select="$latex.biblio.output"/></xsl:message>
<xsl:text>% ------------------------------------------- &#10;</xsl:text>
<xsl:text>%	&#10;</xsl:text>
<xsl:text>%  Bibliography&#10;</xsl:text>
<xsl:text>%	&#10;</xsl:text>
<xsl:text>% -------------------------------------------	&#10;</xsl:text>
<!--<xsl:text>\bibliography{</xsl:text><xsl:value-of select="$latex.bibfiles"/><xsl:text>}&#10;</xsl:text>-->
<xsl:text>\begin{thebibliography}{</xsl:text>
<xsl:value-of select="$latex.bibwidelabel"/>
<xsl:text>}&#10;</xsl:text>
<xsl:call-template name="label.id"/>
<xsl:text>\addcontentsline{toc}{chapter}{\protect\numberline{}Literatura}&#10;</xsl:text>
<xsl:choose>
	<xsl:when test="$latex.biblio.output ='cited'">
		<xsl:apply-templates select="biblioentry" mode="bibliography.cited">
                  <!--			<xsl:sort select="./abbrev"/>
			<xsl:sort select="./@xreflabel"/>
			<xsl:sort select="./@id"/> -->
		</xsl:apply-templates>
	</xsl:when>
	<xsl:when test="$latex.biblio.output ='all'">
		<xsl:apply-templates select="biblioentry" mode="bibliography.all">
                  <!--			<xsl:sort select="./abbrev"/>
			<xsl:sort select="./@xreflabel"/>
			<xsl:sort select="./@id"/>-->
		</xsl:apply-templates>
	</xsl:when>
	<xsl:otherwise>
		<xsl:apply-templates select="biblioentry">
                  <!--			<xsl:sort select="./abbrev"/>
			<xsl:sort select="./@xreflabel"/>
			<xsl:sort select="./@id"/>-->
		</xsl:apply-templates>
	</xsl:otherwise>
</xsl:choose>
<!-- <xsl:apply-templates select="child::*[name(.)!='biblioentry']"/>  -->
<xsl:apply-templates select="bibliodiv"/> 
<xsl:text>&#10;\end{thebibliography}&#10;</xsl:text>
</xsl:template>

  <xsl:template match="biblioentry">
    <xsl:text>\bibitem[</xsl:text>
    <xsl:apply-templates select="abbrev"/>
    <xsl:text>]{</xsl:text>
    <xsl:apply-templates select="abbrev"/>
    <xsl:text>}{\raggedright </xsl:text>
    <xsl:choose>
      <xsl:when test="biblioset">
        <xsl:apply-templates select="biblioset[@relation='article']" mode="bibliocontent"/>
        <xsl:text>In: </xsl:text>
        <xsl:apply-templates select="biblioset[@relation='journal']" mode="bibliocontent"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates select="." mode="bibliocontent"/>
      </xsl:otherwise>
    </xsl:choose>
    
    <xsl:call-template name="label.id"/> 
    <xsl:text>\par}&#10;</xsl:text>
  </xsl:template>

  <xsl:template match="author|editor">
    <xsl:value-of select="surname|othername"/>
    <xsl:if test="firstname">
      <xsl:text>,~</xsl:text>
      <xsl:value-of select="substring(firstname,1,1)"/>
      <xsl:text>.</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="releaseinfo">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="*" mode="bibliocontent">
    <xsl:for-each select=".//author|.//editor">
      <xsl:apply-templates select="."/>
      <xsl:if test="position()!=last()">~-- </xsl:if>
    </xsl:for-each>
    <xsl:if test=".//author|.//editor">
      <xsl:text>: </xsl:text> 
    </xsl:if>
    <xsl:text>{\it </xsl:text>
    <xsl:call-template name="scape">
      <xsl:with-param name="string" select="title"/>
    </xsl:call-template>
    <xsl:if test="subtitle">
      <xsl:text>. </xsl:text>
      <xsl:call-template name="scape">
        <xsl:with-param name="string" select="subtitle"/>
      </xsl:call-template>
    </xsl:if>
    <xsl:text>.} </xsl:text>
    <xsl:value-of select=".//publishername" />
    <xsl:if test=".//publishername and pubdate">, </xsl:if>
    <xsl:if test="publisher/address">
      <xsl:text> </xsl:text>
      <xsl:value-of select="publisher/address"/>
    </xsl:if>
    <xsl:if test="pubdate">
      <xsl:text> </xsl:text>
      <xsl:value-of select="pubdate" />
    </xsl:if>
     <xsl:if test=".//publishername|publisher/address|pubdate">. </xsl:if>
     <xsl:if test="issuenum">
       <!-- <xsl:text>.~</xsl:text> -->
       <xsl:value-of select="issuenum"/><xsl:text>. </xsl:text>
     </xsl:if>
     <xsl:if test="volumenum">
       <xsl:text>Vol.~</xsl:text>
       <xsl:value-of select="volumenum"/><xsl:text>. </xsl:text>
     </xsl:if>
     <xsl:if test="isbn">
       <xsl:text>ISBN~</xsl:text>
       <xsl:value-of select="isbn"/><xsl:text>. </xsl:text>
     </xsl:if>
     <xsl:if test="issn">
       <xsl:text>ISSN~</xsl:text>
       <xsl:value-of select="issn"/>
       <xsl.text>. </xsl.text>
     </xsl:if>
     <xsl:if test="pagenums">
       <xsl:text>Str.~</xsl:text>
       <xsl:value-of select="pagenums"/>
       <xsl:text>. </xsl:text>
     </xsl:if>
   <xsl:apply-templates select="releaseinfo"/>
 </xsl:template>

<!-- inline -->
<xsl:template match="quote">
  <xsl:text>\uv{</xsl:text>
  <xsl:call-template name="inline.charseq"/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template match="guilabel">
  <xsl:call-template name="inline.italicseq"/>
</xsl:template>

<xsl:template match="guimenu">
  <xsl:call-template name="inline.italicseq"/>
</xsl:template>

<xsl:template match="guimenuitem">
  <xsl:call-template name="inline.italicseq"/>
</xsl:template>

<xsl:template name="process.menuchoice">
  <xsl:param name="nodelist" select="guibutton|guiicon|guilabel|guimenu|guimenuitem|guisubmenu|interface"/><!-- not(shortcut) -->
  <xsl:param name="count" select="1"/>

  <xsl:choose>
    <xsl:when test="$count>count($nodelist)"></xsl:when>
    <xsl:when test="$count=1">
      <xsl:apply-templates select="$nodelist[$count=position()]"/>
      <xsl:call-template name="process.menuchoice">
        <xsl:with-param name="nodelist" select="$nodelist"/>
        <xsl:with-param name="count" select="$count+1"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:variable name="node" select="$nodelist[$count=position()]"/>
      <xsl:choose>
        <xsl:when test="name($node)='guimenuitem'
                        or name($node)='guisubmenu'">
          <xsl:text>~$\rightarrow$ </xsl:text>
        </xsl:when>
        <xsl:otherwise>+</xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="$node"/>
      <xsl:call-template name="process.menuchoice">
        <xsl:with-param name="nodelist" select="$nodelist"/>
        <xsl:with-param name="count" select="$count+1"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="inline.monoseq">
  <xsl:text>{\tt </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>}</xsl:text>
</xsl:template>

<xsl:template name="inline.italicseq">
  <xsl:text>{\em </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>\/}</xsl:text>
</xsl:template>

<xsl:template match="literal">
  <xsl:choose>
    <xsl:when test="starts-with(.,'http:')">
      <xsl:text>\url{</xsl:text>
      <xsl:value-of select="."/>
      <xsl:text>}</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="inline.monoseq"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="latex.mapping">
<xsl:param name="object"  select="."/>
<xsl:param name="keyword" select="local-name($object)"/>
<xsl:param name="role" 	  select="begin"/>
<xsl:param name="string"><xsl:value-of select="$object/title"/></xsl:param>
<xsl:param name="use.label"	select="1"/>
<xsl:param name="use.hypertarget" 	select="1"/>
<xsl:variable name="id">
	<xsl:choose>
	<xsl:when test="$object/@id"> <xsl:value-of select="$object/@id"/> </xsl:when>
	<xsl:otherwise> <xsl:value-of select="generate-id($object)"/> </xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="title">
	<xsl:choose>
	<xsl:when test="$string=''">
		<xsl:call-template name="gentext.element.name"/>
	</xsl:when>
	<xsl:otherwise>
		<xsl:value-of select="$string"/>
	</xsl:otherwise>
	</xsl:choose>
</xsl:variable>
<xsl:variable name="latex.mapping.node" 
	select="($latex.mapping.xml/latexbindings/latexmapping[@role=$role]/mapping[@key=$keyword])"/>
<xsl:choose>
	<xsl:when test="$latex.mapping.node/@text!=''">
			<xsl:call-template name="string-replace">
                		<xsl:with-param name="to"><xsl:value-of select="$id"/></xsl:with-param>
                		<xsl:with-param name="from">%id</xsl:with-param>
                		<xsl:with-param name="string">
				<xsl:call-template name="string-replace">
                			<xsl:with-param name="to">
                                          <xsl:call-template name="scape">
                                            <xsl:with-param name="string" select="$title"/>
                                          </xsl:call-template>
                                        </xsl:with-param>
                			<xsl:with-param name="from">%title</xsl:with-param>
                			<xsl:with-param name="string">
						<xsl:value-of select="$latex.mapping.node/@text"/>
					</xsl:with-param>
				</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
		<xsl:for-each select="$latex.mapping.node/line">
			<xsl:call-template name="string-replace">
                		<xsl:with-param name="to"><xsl:value-of select="$id"/></xsl:with-param>
                		<xsl:with-param name="from">%id</xsl:with-param>
                		<xsl:with-param name="string">
				<xsl:call-template name="string-replace">
                			<xsl:with-param name="to">
                                          <xsl:call-template name="scape">
                                            <xsl:with-param name="string" select="$title"/>
                                          </xsl:call-template>
                                        </xsl:with-param>
                			<xsl:with-param name="from">%title</xsl:with-param>
                			<xsl:with-param name="string" select="."/>
				</xsl:call-template>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template name="title.xref">
<xsl:param name="target" select="."/>
<xsl:choose>
	<xsl:when test="name($target) = 'figure'
                    or name($target) = 'example'
                    or name($target) = 'equation'
                    or name($target) = 'table'
                    or name($target) = 'dedication'
                    or name($target) = 'preface'
                    or name($target) = 'bibliography'
                    or name($target) = 'glossary'
                    or name($target) = 'index'
                    or name($target) = 'setindex'
                    or name($target) = 'colophon'">
      <!-- xsl:call-template name="gentext.startquote"/ -->
	<xsl:text>"</xsl:text>
      <xsl:apply-templates select="$target" mode="title.content"/>
      <!-- xsl:call-template name="gentext.endquote"/ -->
	<xsl:text>"</xsl:text>
	</xsl:when>
	<xsl:otherwise>
          <xsl:text>{\em </xsl:text><xsl:apply-templates select="$target" mode="title.content"/><xsl:text>\/}</xsl:text>
	</xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="xref">
<xsl:variable name="targets" select="id(@linkend)"/>
<xsl:variable name="target" select="$targets[1]"/>
<xsl:variable name="refelem" select="local-name($target)"/>
<xsl:call-template name="check.id.unique"><xsl:with-param name="linkend" select="@linkend"/></xsl:call-template>
<xsl:choose>
	<xsl:when test="$refelem=''">
      	<xsl:message><xsl:text>XRef to nonexistent id: </xsl:text><xsl:value-of select="@linkend"/></xsl:message>
		<xsl:text>XrefId[???]</xsl:text>
	</xsl:when>

	<!-- If an xreflabel has been specified for the target ... -->
	<xsl:when test="$target/@xreflabel">
	<xsl:if test="$latex.use.hyperref=1">
	<xsl:text>\hyperlink{</xsl:text><xsl:value-of select="$target/@id"/><xsl:text>}</xsl:text>
	</xsl:if>
	<xsl:text>{[</xsl:text>
	<xsl:call-template name="xref.xreflabel">
		<xsl:with-param name="target" select="$target"/>
	</xsl:call-template>
	<xsl:text>]}</xsl:text>
	</xsl:when>

	<!-- If an xreflabel has not been specified for the target ... -->
	<xsl:otherwise>
        <xsl:choose>
		<xsl:when test="@endterm">
			<xsl:variable name="etargets" select="id(@endterm)"/>
			<xsl:variable name="etarget" select="$etargets[1]"/>
			<xsl:choose>
			<xsl:when test="count($etarget) = 0">
				<xsl:message>
				  <xsl:value-of select="count($etargets)"/>
				  <xsl:text>Endterm points to nonexistent ID: </xsl:text>
				  <xsl:value-of select="@endterm"/>
				</xsl:message>
				<xsl:text>[NONEXISTENT ID]</xsl:text>
			</xsl:when>
			<xsl:otherwise>
			<xsl:if test="$latex.use.hyperref=1">
				<xsl:text>\hyperlink{</xsl:text><xsl:value-of select="$etarget/@id"/><xsl:text>}</xsl:text>
				<xsl:text>{</xsl:text><xsl:apply-templates select="$etarget" mode="xref.text"/><xsl:text>}</xsl:text>
			</xsl:if>
			<xsl:if test="$latex.use.hyperref=0">
				<xsl:apply-templates select="$etarget" mode="xref.text"/>
			</xsl:if>
		      	</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test="$latex.use.hyperref=1">
				<xsl:text>\hyperlink{</xsl:text> <xsl:value-of select="$target/@id"/><xsl:text>}{}</xsl:text>
				<xsl:apply-templates select="$target" mode="xref-to"/>
			</xsl:if>
			<xsl:if test="$latex.use.hyperref=0">
	        	    	<xsl:apply-templates select="$target" mode="xref-to"/>
			</xsl:if>
	        </xsl:otherwise>
	</xsl:choose>
        </xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="tgroup">
<xsl:variable name="align" select="@align"/>
<xsl:variable name="colspecs" select="./colspec"/>
<!-- <xsl:text>{\tt </xsl:text> -->
<xsl:text>\begin{tabular}{</xsl:text>
<xsl:choose>
  <xsl:when test="@tgroupstyle">
    <xsl:text>{</xsl:text><xsl:value-of select="@tgroupstyle"/><xsl:text>}</xsl:text>
  </xsl:when>
  <xsl:otherwise>
    <xsl:if test="../@frame='' or ../@frame='all' or ../@frame='sides'">
	<xsl:text>|</xsl:text>
</xsl:if>
<!--
<xsl:call-template name="table.format.tabular">
     	<xsl:with-param name="cols" select="@cols"/>
</xsl:call-template>-->
<xsl:apply-templates select="colspec"/>
<!--<xsl:if test="../@frame='' or ../@frame='all' or ../@frame='sides'">
	<xsl:text>|</xsl:text>
</xsl:if>-->
  </xsl:otherwise>  
</xsl:choose>
<xsl:text>}&#10;</xsl:text>
<xsl:if test="../@frame!='sides' and ../@frame!='none' and ../@frame!='bottom'">
	<xsl:text>\hline </xsl:text>
</xsl:if>
	<!-- APPLY TEMPLATES -->
	<xsl:apply-templates select="thead|tbody|tfoot"/>
	<!--                 -->
        <xsl:if test="../@frame!='sides' and ../@frame!='none' and ../@frame!='top'">
	<xsl:text>\hline &#10;</xsl:text>
</xsl:if>
<xsl:text>\end{tabular}&#10;</xsl:text>
<!-- <xsl:text>}</xsl:text> -->
</xsl:template>

<xsl:template match="colspec">
  <xsl:text>p{</xsl:text>
  <xsl:value-of select="@colwidth"/>
  <xsl:text>}|</xsl:text>
</xsl:template>

<xsl:template match="thead/row/entry">
{\bf <xsl:apply-templates/><xsl:text>} &amp; </xsl:text> 
</xsl:template>

<xsl:template match="thead/row/entry[position()=last()]">
{\bf <xsl:apply-templates/><xsl:text>} \\ &#10;</xsl:text> 
</xsl:template>

<xsl:template match="tbody/row|tfoot/row">
<xsl:apply-templates/>
	<!-- The rule below the last row in the table is controlled by the 
	Frame attribute of the enclosing Table or InformalTable and the RowSep 
	of the last row is ignored. If unspecified, this attribute is 
	inherited from enclosing elements. -->
        <xsl:if test="position() != last()"> 
	<xsl:text> \hline &#10;</xsl:text>
</xsl:if>
</xsl:template>

<xsl:template match="thead/row">
<xsl:apply-templates/>
	<!-- The rule below the last row in the table is controlled by the 
	Frame attribute of the enclosing Table or InformalTable and the RowSep 
	of the last row is ignored. If unspecified, this attribute is 
	inherited from enclosing elements. -->
	<xsl:text> \hline &#10;</xsl:text>
</xsl:template>

<xsl:template match="processing-instruction('tex')">
  <xsl:value-of select="."/>
</xsl:template>

</xsl:stylesheet>